<?php
/**
 * The Main Addon
 *
 * @package Hestia
 */

/**
 * Class Hestia_Main_Addon
 */
class Hestia_Main_Addon extends Hestia_Abstract_Main {
	/**
	 * Initialize the main addon.
	 */
	public function init() {
		$this->loader->add_action( 'wp_enqueue_scripts', $this, 'enqueue' );
		$this->loader->add_action( 'customize_controls_enqueue_scripts', $this, 'customizer_enqueue' );
		$this->loader->add_action( 'hestia_about_page_array', $this, 'filter_about_page_array_pro' );
		$this->loader->add_action( 'widgets_init', $this, 'initialize_widgets' );
		$this->loader->add_action( 'after_switch_theme', $this, 'migrate_lite_options' );
	}

	/**
	 * Customizer enqueue scripts.
	 */
	public function customizer_enqueue() {

		wp_enqueue_script( 'hestia_scripts_customizer_pro', HESTIA_ADDONS_URI . '/assets/js/scripts-customizer-pro.js', array( 'jquery' ), HESTIA_VENDOR_VERSION, true );
		$control_settings = array(
			'sections_container' => '#accordion-panel-hestia_frontpage_sections > ul, #sub-accordion-panel-hestia_frontpage_sections',
			'blocked_items'      => '#accordion-section-hestia_slider, #accordion-section-hestia_info_jetpack, #accordion-section-hestia_info_woocommerce, #accordion-section-sidebar-widgets-sidebar-big-title',
		);
		wp_localize_script( 'hestia_scripts_customizer_pro', 'shortcode_settings', $control_settings );
	}

	/**
	 * Handle enqueue.
	 */
	public function enqueue() {
		if ( ! is_front_page() ) {
			return;
		}

		if ( get_option( 'show_on_front' ) !== 'page' ) {
			return;
		}

		wp_enqueue_script( 'hestia_scripts_pro', HESTIA_ADDONS_URI . '/assets/js/scripts-pro.js', array( 'jquery' ), HESTIA_VENDOR_VERSION, true );
		wp_enqueue_script( 'jquery-hammer', HESTIA_ADDONS_URI . '/assets/js/hammer.min.js', array( 'jquery' ), HESTIA_VENDOR_VERSION, true );

		// Scroll animations enqueue
		$enable_animations = apply_filters( 'hestia_enable_animations', true );
		if ( $enable_animations ) {
			wp_enqueue_script( 'animate-on-scroll', get_template_directory_uri() . '/inc/addons/assets/js/aos.min.js', HESTIA_VENDOR_VERSION, true );
		}
	}


	/**
	 * Function to filter the about page settings
	 *
	 * @param array $config The about page config array.
	 *
	 * @return array
	 */
	public function filter_about_page_array_pro( $config ) {
		unset( $config['free_pro'] );
		unset( $config['tabs']['free_pro'] );

		$config['menu_name'] = apply_filters( 'hestia_about_page_filter', __( 'About Hestia Pro', 'hestia-pro' ), 'pro_menu_name' );
		$config['page_name'] = apply_filters( 'hestia_about_page_filter', __( 'About Hestia Pro', 'hestia-pro' ), 'pro_page_name' );
		/* translators: s - theme name */
		$config['welcome_title']                            = apply_filters( 'hestia_about_page_filter', sprintf( __( 'Welcome to %s! - Version ', 'hestia-pro' ), 'Hestia Pro' ), 'pro_welcome_title' );
		$config['welcome_content']                          = apply_filters( 'hestia_about_page_filter', esc_html__( 'Hestia Pro is a modern WordPress theme for professionals. It fits creative business, small businesses (restaurants, wedding planners, sport/medical shops), startups, corporate businesses, online agencies and firms, portfolios, ecommerce (WooCommerce), and freelancers. It has a multipurpose one-page design, widgetized footer, blog/news page and a clean look, is compatible with: Flat Parallax Slider, Photo Gallery, Travel Map and Elementor Page Builder . The theme is responsive, WPML, Retina ready, SEO friendly, and uses Material Kit for design.', 'hestia-pro' ), 'pro_welcome_content' );
		$config['support_content']['first']['text']         = esc_html__( 'We want to make sure you have the best experience using Hestia Pro and that is why we gathered here all the necessary informations for you. We hope you will enjoy using Hestia Pro, as much as we enjoy creating great products.', 'hestia-pro' );
		$config['support_content']['second']['button_link'] = 'http://docs.themeisle.com/article/532-hestia-pro-documentation';
		$config['getting_started']['second']['button_link'] = 'http://docs.themeisle.com/article/532-hestia-pro-documentation';
		$config['getting_started']['second']['text']        = esc_html__( 'Need more details? Please check our full documentation for detailed information on how to use Hestia Pro.', 'hestia-pro' );

		$config['recommended_actions']['content']['themeisle-companion']['description'] = __( 'Extend your theme functionality with various modules like Social Media Share Buttons & Icons, custom menu-icons, one click import page templates, page builder addons and free stock featured images.', 'hestia-pro' );

		return $config;
	}

	/**
	 * Register widgets for the theme.
	 *
	 * @since Hestia 1.0
	 * @modified 1.1.40
	 */
	public function initialize_widgets() {
		/**
		 * Array of all the main sidebars registered in the theme
		 */
		$sidebars_array = array(
			'blog-subscribe-widgets' => esc_html__( 'Blog Subscribe Section', 'hestia-pro' ),
		);

		foreach ( $sidebars_array as $sidebar_id => $sidebar_name ) {
			$sidebar_settings = array(
				'name'          => $sidebar_name,
				'id'            => $sidebar_id,
				'before_widget' => '<div id="%1$s" class="widget %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h5>',
				'after_title'   => '</h5>',
			);
			if ( $sidebar_id === 'blog-subscribe-widgets' ) {
				$sidebar_settings['before_widget'] = '';
				$sidebar_settings['after_widget']  = '';
			}

			register_sidebar( $sidebar_settings );
		}
	}

	/**
	 * Import lite options.
	 */
	public function migrate_lite_options() {

		/* import Hestia options */
		$hestia_mods = get_option( 'theme_mods_hestia' );

		if ( ! empty( $hestia_mods ) ) {

			foreach ( $hestia_mods as $hestia_mod_k => $hestia_mod_v ) {
				set_theme_mod( $hestia_mod_k, $hestia_mod_v );
			}
		}
	}

}
